@@ -89,6 +89,9 @@ class DWX_TickData_Downloader_API(object):
             if _verbose is True:
                 print('\n[SUCCESS] {} tick data for {} (hour {}) stored in self._asset_db dict object.\n'.format(_asset, _date, _hour))
 
+            # Close the file
+            self._virtual_dl.close()
+
             # Return the data:
             return self._return_pandas_dataframe_()
         
@@ -135,6 +138,9 @@ class DWX_TickData_Downloader_API(object):
             if _verbose is True:
                 print('\n[SUCCESS] {} tick data for {} (hour {}) stored in self._asset_db dict object.\n'.format(_asset, _date, _hour))
 
+            # Close the file
+            self._virtual_dl.close()
+
             # Return the data:
             return self._return_pandas_dataframe_()
         
@@ -195,6 +201,9 @@ class DWX_TickData_Downloader_API(object):
 
                 # Concat the data:
                 full_dataframe = full_dataframe.append(hour_df_data)
+
+                # Close the file
+                self._virtual_dl.close()
         
             # Case: if file not found
             except Exception as ex:
@@ -256,6 +265,9 @@ class DWX_TickData_Downloader_API(object):
 
                 # Concat the data:
                 full_dataframe = full_dataframe.append(hour_df_data)
+
+                # Close the file
+                self._virtual_dl.close()
         
             # Case: if file not found
             except Exception as ex:
@@ -339,6 +351,9 @@ class DWX_TickData_Downloader_API(object):
 
                     # Concat the data:
                     full_dataframe = full_dataframe.append(hour_df_data)
+
+                    # Close the file
+                    self._virtual_dl.close()
         
                 # Case: if file not found
                 except Exception as ex:
@@ -409,6 +424,9 @@ class DWX_TickData_Downloader_API(object):
 
                     # Concat the data:
                     full_dataframe = full_dataframe.append(hour_df_data)
+
+                    # Close the file
+                    self._virtual_dl.close()
         
                 # Case: if file not found
                 except Exception as ex:
